autowisp.fit_expression.FitTermsParserListener module — AutoWISP documentation

# autowisp.fit_expression.FitTermsParserListener module

## Class Inheritance Diagram

class autowisp.fit_expression.FitTermsParserListener.FitTermsParserListener

  Bases: `ParseTreeListener`

  enterFit_polynomial(ctx: Fit_polynomialContext)
  enterFit_term(ctx: Fit_termContext)
  enterFit_terms_expression(ctx: Fit_terms_expressionContext)
  enterFit_terms_list(ctx: Fit_terms_listContext)
  enterFit_terms_set(ctx: Fit_terms_setContext)
  enterFit_terms_set_cross_product(ctx: Fit_terms_set_cross_productContext)
  exitFit_polynomial(ctx: Fit_polynomialContext)
  exitFit_term(ctx: Fit_termContext)
  exitFit_terms_expression(ctx: Fit_terms_expressionContext)
  exitFit_terms_list(ctx: Fit_terms_listContext)
  exitFit_terms_set(ctx: Fit_terms_setContext)
  exitFit_terms_set_cross_product(ctx: Fit_terms_set_cross_productContext)